Index: main/kofacustom.iuokada/trunk/src/kofacustom/iuokada/applicants/applicant.py
===================================================================
--- main/kofacustom.iuokada/trunk/src/kofacustom/iuokada/applicants/applicant.py	(revision 15937)
+++ main/kofacustom.iuokada/trunk/src/kofacustom/iuokada/applicants/applicant.py	(revision 15942)
@@ -32,5 +32,5 @@
     """
     file_store = getUtility(IExtFileStore)
-    file_store.deleteFileByContext(applicant, attr='stateresult.pdf')
+    file_store.deleteFileByContext(applicant, attr='res_stat.pdf')
     return
 
Index: main/kofacustom.iuokada/trunk/src/kofacustom/iuokada/applicants/browser_templates/applicanteditpage.pt
===================================================================
--- main/kofacustom.iuokada/trunk/src/kofacustom/iuokada/applicants/browser_templates/applicanteditpage.pt	(revision 15937)
+++ main/kofacustom.iuokada/trunk/src/kofacustom/iuokada/applicants/browser_templates/applicanteditpage.pt	(revision 15942)
@@ -43,11 +43,11 @@
           <span tal:replace="view/max_upload_size">10 KB</span>
       </tr>
-      <tr>
+      <tr tal:condition="python: view.context.subtype == 'transfer'">
         <td class="fieldname" i18n:translate="">
           Statement of Result:
         </td>
         <td>
-          <p tal:condition="python: view.file_exists('stateresult.pdf')">
-            <a href="stateresult.pdf"
+          <p tal:condition="python: view.file_exists('res_stat.pdf')">
+            <a href="res_stat.pdf"
                i18n:translate="">
               Download pdf file
@@ -58,5 +58,5 @@
               <div class="btn btn-default btn-file">
                 Select&hellip;
-              <input type="file" name="form.stateresult" />
+              <input type="file" name="form.res_stat" />
               </div>
             </div>
Index: main/kofacustom.iuokada/trunk/src/kofacustom/iuokada/applicants/tests/test_browser.py
===================================================================
--- main/kofacustom.iuokada/trunk/src/kofacustom/iuokada/applicants/tests/test_browser.py	(revision 15937)
+++ main/kofacustom.iuokada/trunk/src/kofacustom/iuokada/applicants/tests/test_browser.py	(revision 15942)
@@ -102,5 +102,5 @@
         print "Sample application_slip.pdf written to %s" % path
 
-    def test_upload_stateresult_by_manager(self):
+    def test_upload_res_stat_by_manager(self):
         # Add trans applicants container
         self.transcontainer = ApplicantsContainer()
@@ -134,5 +134,5 @@
         pdf_content = 'A' * 1024 * 300  # A string of 300 KB size
         pseudo_pdf = StringIO(pdf_content)
-        ctrl = self.browser.getControl(name='form.stateresult')
+        ctrl = self.browser.getControl(name='form.res_stat')
         file_ctrl = ctrl.mech_control
         file_ctrl.add_file(pseudo_pdf, filename='myform.pdf')
@@ -141,5 +141,5 @@
         self.assertTrue('Required input is missing' in self.browser.contents)
         # ... the file has been successfully uploaded
-        pdf_url = self.transapplicant_manage_path.replace('manage', 'stateresult.pdf')
+        pdf_url = self.transapplicant_manage_path.replace('manage', 'res_stat.pdf')
         self.browser.open(pdf_url)
         self.assertEqual(
@@ -149,5 +149,5 @@
         storage = getUtility(IExtFileStore)
         file_id = IFileStoreNameChooser(self.transapplicant).chooseName(
-            attr='stateresult.pdf')
+            attr='res_stat.pdf')
         # The stored file can be fetched
         fd = storage.getFile(file_id)
@@ -156,8 +156,8 @@
         # A file link is displayed on the edit view ...
         self.browser.open(self.transapplicant_manage_path)
-        self.assertTrue('<a href="stateresult.pdf">' in self.browser.contents)
+        self.assertTrue('<a href="res_stat.pdf">' in self.browser.contents)
         # ... and on the dislay view
         self.browser.open(self.transapplicant_view_path)
-        self.assertTrue('stateresult.pdf">Statement of Result</a>'
+        self.assertTrue('res_stat.pdf">Statement of Result</a>'
             in self.browser.contents)
         # Adding file is properly logged
@@ -167,5 +167,5 @@
         self.assertTrue(
             'zope.mgr - kofacustom.iuokada.applicants.browser.CustomApplicantManageFormPage'
-            ' - %s - saved: stateresult'
+            ' - %s - saved: res_stat'
             % (self.transapplicant.applicant_id)
             in logcontent)
Index: main/kofacustom.iuokada/trunk/src/kofacustom/iuokada/applicants/utils.py
===================================================================
--- main/kofacustom.iuokada/trunk/src/kofacustom/iuokada/applicants/utils.py	(revision 15937)
+++ main/kofacustom.iuokada/trunk/src/kofacustom/iuokada/applicants/utils.py	(revision 15942)
@@ -29,4 +29,8 @@
     """A collection of parameters and methods subject to customization.
     """
+
+    #: A tuple of names of files to be copied over
+    #: to students section.
+    FILENAMES = ('res_stat.pdf',)
 
     APP_TYPES_DICT = {
Index: main/kofacustom.iuokada/trunk/src/kofacustom/iuokada/interfaces.py
===================================================================
--- main/kofacustom.iuokada/trunk/src/kofacustom/iuokada/interfaces.py	(revision 15937)
+++ main/kofacustom.iuokada/trunk/src/kofacustom/iuokada/interfaces.py	(revision 15942)
@@ -192,9 +192,9 @@
         )
 
-    make_up_fee = schema.Float(
-        title = _(u'Make-up Fee'),
-        default = 0.0,
-        required = False,
-        )
+    #make_up_fee = schema.Float(
+    #    title = _(u'Make-up Fee'),
+    #    default = 0.0,
+    #    required = False,
+    #    )
 
     iuits_fee = schema.Float(
Index: main/kofacustom.iuokada/trunk/src/kofacustom/iuokada/students/viewlets.py
===================================================================
--- main/kofacustom.iuokada/trunk/src/kofacustom/iuokada/students/viewlets.py	(revision 15937)
+++ main/kofacustom.iuokada/trunk/src/kofacustom/iuokada/students/viewlets.py	(revision 15942)
@@ -98,8 +98,7 @@
     title = _(u'Signature Scan')
     download_name = u'signature'
-    tab_redirect = '?tab2'
 
 class SignatureImage(StudentImage):
-    """Renders acceptance letter scan.
+    """Renders signature scan.
     """
     grok.name('signature')

Index: main/kofacustom.iuokada/trunk/src/kofacustom/iuokada/applicants/browser.py
===================================================================
--- main/kofacustom.iuokada/trunk/src/kofacustom/iuokada/applicants/browser.py	(revision 15937)
+++ main/kofacustom.iuokada/trunk/src/kofacustom/iuokada/applicants/browser.py	(revision 15942)
@@ -126,8 +126,8 @@
         html = ''
         pdf = getUtility(IExtFileStore).getFileByContext(
-            self.context, attr='stateresult.pdf')
+            self.context, attr='res_stat.pdf')
         if pdf:
             html += '<a href="%s">Statement of Result</a>' % self.url(
-                self.context, 'stateresult.pdf')
+                self.context, 'res_stat.pdf')
         return html
 
@@ -174,11 +174,11 @@
     def update(self):
         super(CustomApplicantManageFormPage, self).update()
-        upload_stateresult = self.request.form.get('form.stateresult', None)
-        if upload_stateresult:
-            # We got a fresh stateresult upload
+        upload_res_stat = self.request.form.get('form.res_stat', None)
+        if upload_res_stat:
+            # We got a fresh res_stat upload
             success = handle_file_upload(
-                upload_stateresult, self.context, self, attr='stateresult.pdf')
+                upload_res_stat, self.context, self, attr='res_stat.pdf')
             if success:
-                self.context.writeLogMessage(self, 'saved: stateresult')
+                self.context.writeLogMessage(self, 'saved: res_stat')
             else:
                 self.upload_success = False
@@ -199,5 +199,5 @@
                 return _('Passport picture confirmation box not ticked.')
         if self.context.subtype == 'transfer' and \
-            not store.getFileByContext(self.context, attr=u'stateresult.pdf'):
+            not store.getFileByContext(self.context, attr=u'res_stat.pdf'):
             return _('No statement of result pdf file uploaded.')
         return False
@@ -224,9 +224,9 @@
             return
         super(CustomApplicantEditFormPage, self).update()
-        upload_stateresult = self.request.form.get('form.stateresult', None)
-        if upload_stateresult:
-            # We got a fresh stateresult upload
+        upload_res_stat = self.request.form.get('form.res_stat', None)
+        if upload_res_stat:
+            # We got a fresh res_stat upload
             success = handle_file_upload(
-                upload_stateresult, self.context, self, attr='stateresult.pdf')
+                upload_res_stat, self.context, self, attr='res_stat.pdf')
             if not success:
                 self.upload_success = False
@@ -256,8 +256,8 @@
         return form_fields
 
-class StateResult(grok.View):
+class ResultStatement(grok.View):
     """Renders the pdf form extension for applicants.
     """
-    grok.name('stateresult.pdf')
+    grok.name('res_stat.pdf')
     grok.context(ICustomApplicant)
     grok.require('waeup.viewApplication')
@@ -265,5 +265,5 @@
     def render(self):
         pdf = getUtility(IExtFileStore).getFileByContext(
-            self.context, attr='stateresult.pdf')
+            self.context, attr='res_stat.pdf')
         self.response.setHeader('Content-Type', 'application/pdf')
         return pdf